@@ -1,5 +1,8 @@
-use crate::handlebars_engine::deserialize_context::deserialize_context;
 use crate::out_model::class::Class;
+use crate::{
+    handlebars_engine::deserialize_context::deserialize_context,
+    out_model::class::generic_class::GenericClass,
+};
 use handlebars::{Context, Handlebars, Helper, HelperResult, Output, RenderContext, RenderError};
 
 pub fn cantrips_known(
@@ -16,14 +19,6 @@ pub fn cantrips_known(
         .value()
         .as_i64()
         .ok_or_else(|| RenderError::new("not i64"))? as u8;
-    if let Some(mut i) = class.start_cantrips_known {
-        if level > 3 {
-            i += 1
-        }
-        if level > 9 {
-            i += 1
-        }
-        out.write(i.to_string().as_str())?;
-    }
+    out.write(class.cantrips_known_at_level(level).to_string().as_str())?;
     Ok(())
 }
