@@ -1,6 +1,9 @@
 pub mod class;
+pub mod featlike;
 pub mod index;
 pub mod path_or_struct;
+pub mod races;
 pub mod spell;
+#[cfg(test)]
+pub mod test;
 pub mod vec_of_path_or_struct;
-pub mod featlike;
\ No newline at end of file
