@@ -1,6 +1,8 @@
 use crate::in_model::index::Index as In;
 use crate::out_model;
+use crate::out_model::class::Classes;
 use crate::out_model::index::Index as Out;
+use crate::out_model::spell::Spells;
 
 impl From<In> for Out {
     fn from(val: In) -> Self {
@@ -12,6 +14,7 @@ impl From<In> for Out {
             schools,
             name,
             feats,
+            races,
         } = val;
         let classes = classes
             .into_iter()
@@ -32,7 +35,10 @@ impl From<In> for Out {
                 x
             })
             .collect();
+        let spells = Spells(spells);
+        let classes = Classes(classes);
         let feats = (feats, "feats".to_string()).into();
+        let races = races.into();
         Out {
             classes,
             spells,
@@ -41,6 +47,7 @@ impl From<In> for Out {
             schools,
             name,
             feats,
+            races,
         }
     }
 }
