@@ -1,3 +1,4 @@
+use dnd_wiki_markdown::referencer::Referencer;
 use serde::{Deserialize, Serialize};
 
 use caster_type::CasterType;
@@ -6,20 +7,48 @@ use feature::Feature;
 use multi_class_requirements::MultiClassRequirements;
 use resource::Resource;
 use starting_prof::StartingProf;
-use std::collections::{HashMap, HashSet};
+use std::{
+    borrow::Cow,
+    collections::{HashMap, HashSet},
+    ops::Deref,
+};
+
+use crate::text_utils::file_name_sanitize;
 
 use self::{generic_class::GenericClass, subclasses::Subclasses};
 
 pub mod caster_type;
 pub mod equipment;
 pub mod feature;
+pub mod generic_class;
 pub mod multi_class_requirements;
 pub mod resource;
 pub mod starting_prof;
 pub mod subclass;
 pub mod subclasses;
-pub mod generic_class;
 
+#[derive(Debug, Clone, Deserialize, Serialize)]
+pub struct Classes(pub Vec<Class>);
+
+impl Deref for Classes {
+    type Target = Vec<Class>;
+
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+
+impl Referencer for Classes {
+    fn prop(&self, prop: &str) -> Option<&dyn Referencer> {
+        self.iter()
+            .find(|x| x.name() == prop)
+            .map(|x| x as &dyn Referencer)
+    }
+
+    fn value(&self) -> Cow<str> {
+        "".into()
+    }
+}
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct Class {
     pub name: String,
@@ -36,6 +65,22 @@ pub struct Class {
     pub subclasses: Subclasses,
 }
 
+impl Referencer for Class {
+    fn prop(&self, prop: &str) -> Option<&dyn Referencer> {
+        
+
+        self.subclasses
+            .entries
+            .iter()
+            .find(|x| x.name() == prop)
+            .map(|x| x as &dyn Referencer)
+    }
+
+    fn value(&self) -> Cow<str> {
+        format!("./classes/{}/index.html", file_name_sanitize(self.name())).into()
+    }
+}
+
 impl GenericClass for Class {
     fn name(&self) -> &str {
         self.name.as_str()
@@ -60,4 +105,4 @@ impl GenericClass for Class {
     fn class_resources(&self) -> &HashMap<String, Resource> {
         &self.class_resources
     }
-}
\ No newline at end of file
+}
