@@ -1,11 +1,16 @@
+use dnd_wiki_markdown::referencer::Referencer;
+use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
-use serde::{Deserialize, Serialize};
+use crate::text_utils::file_name_sanitize;
 
-use super::{caster_type::CasterType, feature::Feature, generic_class::GenericClass, resource::Resource};
+use super::{
+    caster_type::CasterType, feature::Feature, generic_class::GenericClass, resource::Resource,
+};
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct Subclass {
+    pub parent_class_name: String,
     pub name: String,
     pub level: u8,
     pub flavour_text: String,
@@ -15,6 +20,21 @@ pub struct Subclass {
     pub class_resources: HashMap<String, Resource>,
 }
 
+impl Referencer for Subclass {
+    fn prop(&self, _: &str) -> Option<&dyn Referencer> {
+        None
+    }
+
+    fn value(&self) -> std::borrow::Cow<str> {
+        format!(
+            "./classes/{}/{}.html",
+            file_name_sanitize(&self.parent_class_name),
+            file_name_sanitize(self.name())
+        )
+        .into()
+    }
+}
+
 impl GenericClass for Subclass {
     fn name(&self) -> &str {
         self.name.as_str()
