@@ -3,26 +3,43 @@ use std::collections::{HashMap, HashSet};
 use std::error::Error;
 use std::ops::Deref;
 
-use crate::out_model::class::Class;
 use crate::out_model::crs::Crs;
-use crate::out_model::spell::Spell;
 use crate::text_utils::file_name_sanitize;
 use crate::{handlebars_definitions, handlebars_engine as engine};
+use dnd_wiki_markdown::referencer::Referencer;
 use serde::{Deserialize, Serialize};
 
+use super::class::Classes;
 use super::featlikes::Featlikes;
-use super::references::References;
+use super::races::Races;
+use super::spell::Spells;
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct Index {
-    pub classes: Vec<Class>,
-    pub spells: Vec<Spell>,
+    pub classes: Classes,
+    pub spells: Spells,
     pub style: String,
     #[serde(rename = "static")]
     pub static_folder: String,
     pub schools: HashSet<String>,
     pub name: String,
     pub feats: Featlikes,
+    pub races: Races,
+}
+
+impl Referencer for Index {
+    fn prop(&self, prop: &str) -> Option<&dyn Referencer> {
+        match prop {
+            "class" => Some(&self.classes),
+            "spells" => Some(&self.spells),
+            "feats" => Some(b"./feats.html" as &dyn Referencer),
+            _ => None,
+        }
+    }
+
+    fn value(&self) -> Cow<str> {
+        "".into()
+    }
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
@@ -30,7 +47,7 @@ pub struct Metadata {
     pub name: String,
     pub path_to_parent: String,
     pub path_to_index: String,
-    pub references: Crs<References>,
+    pub index: Crs<Index>,
     pub schools: HashSet<String>,
 }
 
@@ -65,13 +82,11 @@ pub struct MetadataWrapper<T> {
 
 impl Index {
     pub fn build(&self) -> Result<HashMap<Cow<str>, String>, Box<dyn Error>> {
-        let references = References::from(self);
-        let r = Crs::new(&references);
         let metadata = Metadata {
-            references: r,
+            index: Crs::new(&self),
             name: self.name.to_string(),
-            path_to_index: String::new(),
-            path_to_parent: String::new(),
+            path_to_index: "./".into(),
+            path_to_parent: "./index.html".into(),
             schools: self.schools.clone(),
         };
         let mut map: HashMap<Cow<str>, String> = HashMap::new();
@@ -84,7 +99,8 @@ impl Index {
             engine::feats::engine().render(
                 &metadata
                     .clone()
-                    .index_parent("./index.html")
+                    .index("./")
+                    .parent("./index.html")
                     .new_wrapper(self.feats.clone()),
             )?,
         );
@@ -93,23 +109,19 @@ impl Index {
             engine::spells::engine().render(
                 &metadata
                     .clone()
-                    .index_parent("../")
+                    .index("../")
+                    .parent("../index.html")
                     .new_wrapper(self.spells.clone()),
             )?,
         );
-        for spell in &self.spells {
+        for spell in self.spells.deref() {
             map.insert(
                 format!("spells/{}.html", file_name_sanitize(spell.name.as_str())).into(),
-                engine::spell::engine().render(
-                    &metadata
-                        .clone()
-                        .parent("./index.html")
-                        .index("../index.html")
-                        .new_wrapper(spell.clone()),
-                )?,
+                engine::spell::engine()
+                    .render(&metadata.clone().index("../").new_wrapper(spell.clone()))?,
             );
         }
-        for class in &self.classes {
+        for class in self.classes.deref() {
             map.insert(
                 format!(
                     "classes/{}/index.html",
@@ -119,7 +131,8 @@ impl Index {
                 engine::class::engine().render(
                     &metadata
                         .clone()
-                        .index_parent("../../index.html")
+                        .index("../../")
+                        .parent("../../index.html")
                         .new_wrapper(class.clone()),
                 )?,
             );
@@ -135,12 +148,34 @@ impl Index {
                         &metadata
                             .clone()
                             .parent("../../index.html")
-                            .index("../../index.html")
+                            .index("../../")
                             .new_wrapper(subclass.clone()),
                     )?,
                 );
             }
         }
+        map.insert(
+            "races/index.html".into(),
+            engine::races::engine().render(
+                &metadata
+                    .clone()
+                    .index("../")
+                    .parent("../index.html")
+                    .new_wrapper(self.races.clone()),
+            )?,
+        );
+        for race in self.races.0.iter().flat_map(|(_, (_, x))| x) {
+            map.insert(
+                format!("races/{}.html", file_name_sanitize(&race.name)).into(),
+                engine::race::engine().render(
+                    &metadata
+                        .clone()
+                        .index("../")
+                        .parent("./index.html")
+                        .new_wrapper(race.clone()),
+                )?,
+            );
+        }
         map.insert("sw.js".into(), handlebars_definitions::sw().to_string());
         Ok(map)
     }
