@@ -1,6 +1,6 @@
 pub mod class;
 pub mod index;
 pub mod spell;
-pub mod references;
 pub mod crs;
-pub mod featlikes;
\ No newline at end of file
+pub mod featlikes;
+pub mod races;
\ No newline at end of file
